==> xfxwidgets-1.9.96.tar.gz: lib/XfxUtils.dart <==
import 'dart:typed_data';
import 'package:flutter/material.dart';
import 'package:xcommonwidgets/xcommonwidgets.dart';
import 'package:xfxbase/XFDataItem.dart';
import 'package:xfxwidgets/xPDFviewer.dart';
import 'package:flutter_cached_pdfview/flutter_cached_pdfview.dart';
import 'package:flutter_email_sender/flutter_email_sender.dart';
import 'package:xtoolspackage/xtoolspackage.dart';

abstract class XfxUtils {
  static String GetStringFromValue(dynamic value, {XProp? colForXDataItem = null}) {
    if (value is XFDataItem) {
      var str = value[colForXDataItem!.col_Name].toString();
      return str;
    } else if (value is XEnumDef) {
      return value.label;
    } else
      return value.toString();
  }

  static String xddValueToString(Object? value, Iterable<XProp> colsOfXFdataItemToShow) {
    if (value is XFDataItem) {
      return xddValueToString_XFD(value, colsOfXFdataItemToShow);
    } else if (value is XEnumDef) {
      return value.label;
    } else
      return value.toString();
  }

  static String xddValueToString_XFD(XFDataItem value, Iterable<XProp> colsOfXFdataItemToShow) {
    var str = "";
    colsOfXFdataItemToShow.forEach((element) {
      str += (str.isEmpty ? "" : " ") + value[element.col_Name].toString();
    });
    return str;
  }

  static Future xGenPDF_UI(
    void Function(void Function()) parentState,
    BuildContext context,
    Future<List<String?>?> Function() getUrls_API,
    XFDataItem obj_Parent, {
    Future<Uint8List?> Function()? getBytesDoc_API,
    String? waiterMessage,
    bool? isBusy_ParentPage,
    List<String?>? emailsCli,
    String? email_Body,
    String? email_Subject,
    List<String>? liAddons_FilesPath,
    String? Function(String link)? pagePDF_title,
    bool saveObjBeforeView = true,
    Future Function()? onSaveObj,
  }) async {
    if (saveObjBeforeView) {
      parentState(() {
        waiterMessage = "Sto Preparando il Documento da Visualizzare";
        isBusy_ParentPage = true;
      });
      var x = await xDialog(context, BTN_Label_YES: "Salva", BTNno_Visible: false, BTN_Label_NO: "", title: "Hai modificato i Dati, per vedere il Documento salva i dati.", onPressed: () {
        Navigator.pop(context, true);
      });
      if (x != null && x) {
        await onSaveObj!();
        await xCMD_GenPDF_Page(parentState, context, getUrls_API, obj_Parent, getBytesDoc_API: getBytesDoc_API, email_Body: email_Body, email_Subject: email_Subject, emailsCli: emailsCli, isBusy_ParentPage: isBusy_ParentPage, liAddons_FilesPath: liAddons_FilesPath, waiterMessage: waiterMessage);
      }
    } else {
      await xCMD_GenPDF_Page(parentState, context, getUrls_API, obj_Parent, getBytesDoc_API: getBytesDoc_API, email_Body: email_Body, email_Subject: email_Subject, emailsCli: emailsCli, isBusy_ParentPage: isBusy_ParentPage, liAddons_FilesPath: liAddons_FilesPath, waiterMessage: waiterMessage);
    }
  }

  ///Dialog Generico da Utilizzare
  static Future<bool?> xDialog(BuildContext context, {Widget? contentWidget, String? title, String? BTN_Label_YES, String? BTN_Label_NO, bool BTNno_Visible = true, String? BTN_Label, Function()? onPressed}) async {
    return await showDialog<bool>(
        barrierDismissible: false,
        context: context,
        builder: (context) {
          return XAlertDialog(
              title_Text: title ?? "Modifica il campo qui sotto:",
              title_Style: XStyles.xStyTextForTextBase(textColor: XColors.foregroundLight),
              child: contentWidget ?? Container(),
              actionsBTNarea_Child: Row(mainAxisAlignment: MainAxisAlignment.center, children: [
                Expanded(
                    child: BTNno_Visible
                        ? XBtnbase(
                            label: BTN_Label_NO ?? "Annulla",
                            label_Style: XStyles.xStyTextForSubLabel(textColor: XColors.undo),
                            onPressed: () => Navigator.pop(context, false),
                          )
                        : Container()),
                SizedBox(width: 10),
                Expanded(
                    child: XBtnbase(
                  label: BTN_Label_YES ?? "OK, avanti..",
                  label_Style: XStyles.xStyTextForSubLabel(textColor: XColors.done),
                  onPressed: onPressed,
                ))
              ]));
        });
  }

  static Future xCMD_GenPDF_Page(
    void Function(void Function()) parentState,
    BuildContext context,
    Future<List<String?>?> Function() getUrls_API,
    XFDataItem obj_Parent, {
    Future<Uint8List?> Function()? getBytesDoc_API,
    String? waiterMessage,
    bool? isBusy_ParentPage,
    List<String?>? emailsCli,
    String? email_Body,
    String? email_Subject,
    List<String>? liAddons_FilesPath,
  }) async {
    parentState(() {
      waiterMessage != null ? waiterMessage = "Sto Preparando il Preventivo da Visualizzare" : null;
      isBusy_ParentPage != null ? isBusy_ParentPage = true : null;
    });
    var urls = await getUrls_API();
    if (urls == null || urls.isEmpty) {
      return XAlertDialog.alertClose(context, titleStyle: XStyles.xStyTextForDescr(textColor: Colors.amber), titleText: "Scusa ma non riesco a generare il Preventivo, controlla i dati o se non lo hai ancora fatto inserisci un dettaglio.");
    } else {
      await xOpenPDF(urls, context, obj_Parent, getBytesDoc_API: getBytesDoc_API, emailsCli: emailsCli, email_Body: email_Body, email_Subject: email_Subject, liAddons_FilesPath: liAddons_FilesPath);
    }
    parentState(() {
      waiterMessage != null ? waiterMessage = "" : null;
      isBusy_ParentPage != null ? isBusy_ParentPage = false : null;
    });
  }

  static Future xOpenPDF(
    List<String?>? urls,
    BuildContext context,
    XFDataItem obj_Parent, {
    Future<Uint8List?> Function()? getBytesDoc_API,
    List<String?>? emailsCli,
    String? email_Body,
    String? email_Subject,
    List<String>? liAddons_FilesPath,
    String? Function(String link)? pagePDF_title,
  }) async {
    List<XpdfScreenItem> liWidgetsPDF = List<XpdfScreenItem>.empty(growable: true);
    if (urls!.isEmpty) return;
    for (var x in urls) {
      var r = PDF(enableSwipe: true).fromUrl(x!);
      liWidgetsPDF.add(XpdfScreenItem(title: pagePDF_title != null ? (pagePDF_title(x) ?? "") : "Preventivo", widgetToView: r));
    }
    var bytesDoc;
    if (getBytesDoc_API != null) {
      bytesDoc = await getBytesDoc_API();
    }
    await Navigator.push<void>(
        context,
        MaterialPageRoute<void>(
            builder: (BuildContext context) => XPDFScreen<XFDataItem>(
                liWidgetPDF: liWidgetsPDF,
                getDoc_Bytes: bytesDoc,
                itemInEdit: obj_Parent,
                sendEmailBTN_visible: emailsCli != null ? true : false,
                btnChangePDF_Visible: false,
                email: emailsCli != null
                    ? (XFDataItem item, liFiles) {
                        var liFilesUI = liFiles.map((e) => e.path).toList();
                        liAddons_FilesPath != null ? liFilesUI.addAll(liAddons_FilesPath) : null;
                        return Email(
                          body: email_Body ?? 'Buongiorno',
                          subject: email_Subject ?? 'Preventivo rif.',
                          recipients: emailsCli.map((e) => e ?? "").toList(),
                          attachmentPaths: liFilesUI,
                          isHTML: false,
                        );
                      }
                    : null)));
  }
}

==> xfxwidgets-1.10.8.tar.gz: lib/XfxUtils.dart <==
import 'dart:typed_data';
import 'package:flutter/material.dart';
import 'package:xcommonwidgets/xcommonwidgets.dart';
import 'package:xfxbase/XFDataItem.dart';
import 'package:xfxwidgets/xPDFviewer.dart';
import 'package:flutter_cached_pdfview/flutter_cached_pdfview.dart';
import 'package:flutter_email_sender/flutter_email_sender.dart';
import 'package:xtoolspackage/xtoolspackage.dart';

abstract class XfxUtils {
  static String GetStringFromValue(dynamic value, {XProp? colForXDataItem = null}) {
    if (value is XFDataItem) {
      var str = value[colForXDataItem!.col_Name].toString();
      return str;
    } else if (value is XEnumDef) {
      return value.label;
    } else
      return value.toString();
  }

  static String xddValueToString(Object? value, Iterable<XProp> colsOfXFdataItemToShow) {
    if (value is XFDataItem) {
      return xddValueToString_XFD(value, colsOfXFdataItemToShow);
    } else if (value is XEnumDef) {
      return value.label;
    } else
      return value.toString();
  }

  static String xddValueToString_XFD(XFDataItem value, Iterable<XProp> colsOfXFdataItemToShow) {
    var str = "";
    colsOfXFdataItemToShow.forEach((element) {
      str += (str.isEmpty ? "" : " ") + value[element.col_Name].toString();
    });
    return str;
  }

  static Future xGenPDF_UI(
    void Function(void Function()) parentState,
    BuildContext context,
    Future<List<String?>?> Function() getUrls_API,
    XFDataItem obj_Parent, {
    Future<Uint8List?> Function()? getBytesDoc_API,
    String? waiterMessage,
    bool? isBusy_ParentPage,
    List<String?>? emailsCli,
    String? email_Body,
    String? email_Subject,
    List<String>? liAddons_FilesPath,
    String? Function(String link)? pagePDF_title,
    bool saveObjBeforeView = true,
    Future Function()? onSaveObj,
  }) async {
    if (saveObjBeforeView) {
      parentState(() {
        waiterMessage = "Sto Preparando il Documento da Visualizzare";
        isBusy_ParentPage = true;
      });
      var x = await xDialog(context, BTN_Label_YES: "Salva", BTNno_Visible: false, BTN_Label_NO: "", title: "Hai modificato i Dati, per vedere il Documento salva i dati.", onPressed: () {
        Navigator.pop(context, true);
      });
      if (x != null && x) {
        await onSaveObj!();
        await xCMD_GenPDF_Page(parentState, context, getUrls_API, obj_Parent, getBytesDoc_API: getBytesDoc_API, email_Body: email_Body, email_Subject: email_Subject, emailsCli: emailsCli, isBusy_ParentPage: isBusy_ParentPage, liAddons_FilesPath: liAddons_FilesPath, waiterMessage: waiterMessage);
      }
    } else {
      await xCMD_GenPDF_Page(parentState, context, getUrls_API, obj_Parent, getBytesDoc_API: getBytesDoc_API, email_Body: email_Body, email_Subject: email_Subject, emailsCli: emailsCli, isBusy_ParentPage: isBusy_ParentPage, liAddons_FilesPath: liAddons_FilesPath, waiterMessage: waiterMessage);
    }
  }

  ///Dialog Generico da Utilizzare
  static Future<bool?> xDialog(BuildContext context, {Widget? contentWidget, String? title, String? BTN_Label_YES, String? BTN_Label_NO, bool BTNno_Visible = true, String? BTN_Label, Function()? onPressed}) async {
    return await showDialog<bool>(
        barrierDismissible: false,
        context: context,
        builder: (context) {
          return XAlertDialog(
              title_Text: title ?? "Modifica il campo qui sotto:",
              title_Style: XStyles.xStyTextForTextBase(textColor: XColors.foregroundLight),
              child: contentWidget ?? Container(),
              actionsBTNarea_Child: Row(mainAxisAlignment: MainAxisAlignment.center, children: [
                Expanded(
                    child: BTNno_Visible
                        ? XBtnbase(
                            label: BTN_Label_NO ?? "Annulla",
                            label_Style: XStyles.xStyTextForSubLabel(textColor: XColors.undo),
                            onPressed: () => Navigator.pop(context, false),
                          )
                        : Container()),
                SizedBox(width: 10),
                Expanded(
                    child: XBtnbase(
                  label: BTN_Label_YES ?? "OK, avanti..",
                  label_Style: XStyles.xStyTextForSubLabel(textColor: XColors.done),
                  onPressed: onPressed,
                ))
              ]));
        });
  }

  static Future xCMD_GenPDF_Page(
    void Function(void Function()) parentState,
    BuildContext context,
    Future<List<String?>?> Function() getUrls_API,
    XFDataItem obj_Parent, {
    Future<Uint8List?> Function()? getBytesDoc_API,
    String? waiterMessage,
    bool? isBusy_ParentPage,
    List<String?>? emailsCli,
    String? email_Body,
    String? email_Subject,
    List<String>? liAddons_FilesPath,
  }) async {
    parentState(() {
      waiterMessage != null ? waiterMessage = "Sto Preparando il Preventivo da Visualizzare" : null;
      isBusy_ParentPage != null ? isBusy_ParentPage = true : null;
    });
    var urls = await getUrls_API();
    if (urls == null || urls.isEmpty) {
      return XAlertDialog.alertClose(context, titleStyle: XStyles.xStyTextForDescr(textColor: Colors.amber), titleText: "Scusa ma non riesco a generare il Preventivo, controlla i dati o se non lo hai ancora fatto inserisci un dettaglio.");
    } else {
      await xOpenPDF(urls, context, obj_Parent, getBytesDoc_API: getBytesDoc_API, emailsCli: emailsCli, email_Body: email_Body, email_Subject: email_Subject, liAddons_FilesPath: liAddons_FilesPath);
    }
    parentState(() {
      waiterMessage != null ? waiterMessage = "" : null;
      isBusy_ParentPage != null ? isBusy_ParentPage = false : null;
    });
  }

  static Future xOpenPDF(
    List<String?>? urls,
    BuildContext context,
    XFDataItem obj_Parent, {
    Future<Uint8List?> Function()? getBytesDoc_API,
    List<String?>? emailsCli,
    String? email_Body,
    String? email_Subject,
    List<String>? liAddons_FilesPath,
    String? Function(String link)? pagePDF_title,
  }) async {
    List<XpdfScreenItem> liWidgetsPDF = List<XpdfScreenItem>.empty(growable: true);
    if (urls!.isEmpty) return;
    for (var x in urls) {
      var r = PDF(enableSwipe: true).fromUrl(x!);
      liWidgetsPDF.add(XpdfScreenItem(title: pagePDF_title != null ? (pagePDF_title(x) ?? "") : "Preventivo", widgetToView: r));
    }
    // var bytesDoc;
    // if (getBytesDoc_API != null) {
    //   bytesDoc = await getBytesDoc_API();
    // }
    await Navigator.push<void>(
        context,
        MaterialPageRoute<void>(
            builder: (BuildContext context) => XPDFScreen<XFDataItem>(
                liWidgetPDF: liWidgetsPDF,
                urlPDF: urls.first!,
                itemInEdit: obj_Parent,
                sendEmailBTN_visible: emailsCli != null ? true : false,
                btnChangePDF_Visible: false,
                email: emailsCli != null
                    ? (XFDataItem item, liFiles) {
                        var liFilesUI = liFiles.map((e) => e.path).toList();
                        liAddons_FilesPath != null ? liFilesUI.addAll(liAddons_FilesPath) : null;
                        return Email(
                          body: email_Body ?? 'Buongiorno',
                          subject: email_Subject ?? 'Preventivo rif.',
                          recipients: emailsCli.map((e) => e ?? "").toList(),
                          attachmentPaths: liFilesUI,
                          isHTML: false,
                        );
                      }
                    : null)));
  }
}
